@@ -2,7 +2,7 @@
 * This file is part of Converseen, an open-source batch image converter
 * and resizer.
 *
-* (C) Francesco Mondello 2009-2015
+* (C) Francesco Mondello 2009-2017
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@
 */
 
 #include <QDir>
-#include <QDesktopServices>
+#include <QStandardPaths>
 #include "inisettings.h"
 
 #define INIFILENAME ".converseen.conf"
@@ -37,7 +37,7 @@ IniSettings::IniSettings(QObject *parent) :
 
 void IniSettings::init()
 {
-	QString myPath =  QDesktopServices::storageLocation(QDesktopServices::DataLocation);
+	QString myPath =  QStandardPaths::writableLocation(QStandardPaths::DataLocation);
 	QString iniPath = QString("%1/%2").arg(myPath).arg(INIFILENAME);
 
     settings = new QSettings(iniPath, QSettings::IniFormat);
