@@ -2,7 +2,7 @@
 * This file is part of Converseen, an open-source batch image converter
 * and resizer.
 *
-* (C) Francesco Mondello 2009-2015
+* (C) Francesco Mondello 2009-2017
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -40,7 +40,7 @@ using namespace std;
 
 // TODO: Inserire funzione per sostituire tutte le immagini
 
-MainWindowImpl::MainWindowImpl(QWidget * parent, Qt::WFlags f)
+MainWindowImpl::MainWindowImpl(QWidget * parent, Qt::WindowFlags f)
     : QMainWindow(parent, f)
 {
     setupUi(this);
@@ -93,7 +93,7 @@ MainWindowImpl::MainWindowImpl(QWidget * parent, Qt::WFlags f)
     adjustSize();
     dockWidget->adjustSize();
 
-    treeWidget->header()->setResizeMode(0, QHeaderView::ResizeToContents);
+    treeWidget->header()->setSectionResizeMode(0, QHeaderView::ResizeToContents);
 
     loadOptions();
 
@@ -627,7 +627,7 @@ void MainWindowImpl::loadQuality()
 {
     jpgQuality = IniSettings::jpgQuality();
     pngQuality = IniSettings::pngQuality();
-    m_resamplingFilter = (FilterTypes)IniSettings::latestInterpFiltIdx();
+    m_resamplingFilter = (IMFilterType)IniSettings::latestInterpFiltIdx();
 }
 
 void MainWindowImpl::removeItems()
